constants library

Enums

BuildMode

Constants

buildModeFlag → const String
currentVersion → const String
defaultIdleTimeout → const Duration
Daemon shuts down after this timeout if there is no active connection.
fileChangeEventErrorCode → const int
fileChangeStreamClosedErrorCode → const int
logEndMarker → const String
logStartMarker → const String
These are used when serializing log messages over stdout.
optionsSkew → const String
readyToConnectLog → const String
versionSkew → const String

Functions

daemonWorkspace(String workingDirectory, {String? daemonSharedPath}) String
The directory where lock files are kept.
lockFilePath(String workingDirectory, {String? daemonSharedPath}) String
Used to ensure that only one instance of this daemon is running at a time.
optionsFilePath(String workingDirectory, {String? daemonSharedPath}) String
Used to signal to clients the current set of options of the build daemon.
portFilePath(String workingDirectory, {String? daemonSharedPath}) String
Used to signal to clients on what port the running daemon is listening.
versionFilePath(String workingDirectory, {String? daemonSharedPath}) String
Used to signal to clients the current version of the build daemon.