DefaultBuildResult class abstract

Implemented types

Constructors

DefaultBuildResult([void b(DefaultBuildResultBuilder)])
factory

Properties

buildId → String?
no setterinherited
error → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isCached → bool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → BuildStatus
no setterinherited
target → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DefaultBuildResultBuilder)) → DefaultBuildResult
Rebuilds the instance.
inherited
toBuilder() → DefaultBuildResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DefaultBuildResult>
no setter