DefaultBuildTarget class abstract

Implemented types

Constructors

DefaultBuildTarget([void b(DefaultBuildTargetBuilder)])
factory

Properties

blackListPatterns → BuiltSet<RegExp>
A set of file path patterns to match changes against.
no setter
buildFilters → BuiltSet<String>?
A set of globs patterns for files to build.
no setter
hashCode → int
The hash code for this object.
no setterinherited
outputLocation → OutputLocation?
no setter
reportChangedAssets → bool
Whether the BuildResults events emitted for this target should report a list of assets invalidated in a build.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(DefaultBuildTargetBuilder)) → DefaultBuildTarget
Rebuilds the instance.
inherited
toBuilder() → DefaultBuildTargetBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<DefaultBuildTarget>
no setter