BuildTargetRequest class abstract

Registers a build target to be built by the daemon.

Note this does not trigger a build.

Constructors

BuildTargetRequest([void updates(BuildTargetRequestBuilder b)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → BuildTarget
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(BuildTargetRequestBuilder)) → BuildTargetRequest
Rebuilds the instance.
inherited
toBuilder() → BuildTargetRequestBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<BuildTargetRequest>
no setter