ServerLog class abstract

Roughly matches the LogRecord class from package:logging.

Constructors

ServerLog([void updates(ServerLogBuilder b)])
factory
ServerLog.fromLogRecord(LogRecord record)
factory

Properties

error → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
level → Level
no setter
loggerName → String?
no setter
message → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ServerLogBuilder)) → ServerLog
Rebuilds the instance.
inherited
toBuilder() → ServerLogBuilder
Converts the instance to a builder B.
inherited
toLogRecord() → LogRecord
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ServerLog>
no setter