build abstract method
Builds targets for the given file changes.
In auto build mode, an empty changes list indicates an explicit build request as distinct from a file watch based request.
Implementation
Future<void> build(Set<BuildTarget> targets, Iterable<WatchEvent> changes);